@@ -167,6 +167,7 @@ namespace giac {
   vecteur gen2continued_fraction(const gen & g,int n,GIAC_CONTEXT);
   gen float2rational(double d_orig,double eps,GIAC_CONTEXT);
 
+  extern const unary_function_ptr * const  at_ggbalt;
   extern const unary_function_ptr * const  at_preval;
   extern const unary_function_ptr * const  at_dotprod;
   extern const unary_function_ptr * const  at_mean;
@@ -174,6 +175,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_stddev;
   extern const unary_function_ptr * const  at_variance;
   extern const unary_function_ptr * const  at_lagrange;
+  extern const unary_function_ptr * const  at_interp;
   extern const unary_function_ptr * const  at_reorder;
   extern const unary_function_ptr * const  at_adjoint_matrix;
   extern const unary_function_ptr * const  at_equal2diff;
@@ -238,6 +240,23 @@ namespace giac {
 
   bool has_undef_stringerr(const gen & g,std::string & err);
 
+  // step by step utilities
+  // poi=point of interest, tvi=table of variation
+  // asym=list of asymptotes, crit=critical points, inflex=inflection points
+  int step_func(const gen & f,const gen & x,gen & xmin,gen&xmax,vecteur & poig,vecteur & tvi,gen & periode,vecteur & asym,vecteur & parab,vecteur & crit,vecteur & inflex,bool printtvi,bool exactlegende,GIAC_CONTEXT,bool do_inflex=true);
+  extern const unary_function_ptr * const  at_tabvar;
+  int step_param(const gen & f,const gen & g,const gen & t,gen & tmin,gen&tmax,vecteur & poi,vecteur & tvi,bool printtvi,bool exactlegende,GIAC_CONTEXT);
+  // translate HTML Xcas for Firefox link to a giac list of commands
+  std::string link2giac(const std::string & s,GIAC_CONTEXT);
+  // parse %ab to char from html link, e.g. %20 to space
+  std::string html_filter(const std::string & s);
+
+  extern const unary_function_ptr * const  at_range ;
+  gen _range(const gen & args,GIAC_CONTEXT);
+
+  extern const unary_function_ptr * const  at_find ;
+  gen _find(const gen & args,GIAC_CONTEXT);
+  extern const unary_function_ptr * const  at_add_autosimplify;
 
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
