@@ -67,8 +67,8 @@ enum Fl_Color {	// standard colors
 //#ifndef LP64
 typedef ptrdiff_t Int;
 //#else typedef signed long Int; #endif
-#include "Colors.h"
-//#include "../../src/Colors.h"
+//#include "Colors.h"
+#include "../../src/Colors.h"
 enum Fl_Color {
   FL_BLACK = ColorBlack,
   FL_WHITE = ColorWhite,
@@ -279,7 +279,9 @@ namespace giac {
 
   gen _erase(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_erase;
-
+  
+  extern int pixon_size; 
+  vecteur merge_pixon(const vecteur & v);
   gen _pixon(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_pixon;
 
@@ -797,7 +799,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_Bezier;
 
 
-#if defined(GIAC_GENERIC_CONSTANTS) || (defined(VISUALC) && !defined(RTOS_THREADX)) || defined(__x86_64__)
+#if defined(GIAC_GENERIC_CONSTANTS) || (defined(VISUALC) && !defined(RTOS_THREADX)) || defined(x86_64)
   extern unary_function_ptr point_sommet_tab_op[];
   extern unary_function_ptr nosplit_polygon_function[];
   extern unary_function_ptr measure_functions[];
